FITLAND_VERSION = "0.2.2"
FITLAND_VERSION_NAME = "Version 0.2.2"
FITLAND_VERSION_DATE = "09/01/2022"
FITLAND_VERSION_TIME = "15:39 CST"
FITLAND_VERSION_AUTHOR = "Erick Salas"

version = {
	"id": FITLAND_VERSION,
	"name": FITLAND_VERSION_NAME,
	"date": FITLAND_VERSION_DATE,
	"time": FITLAND_VERSION_TIME,
	"author": FITLAND_VERSION_AUTHOR
}
