NOTIFICATION_TYPE_NONE = 0

# types of notification templates
NOTIFICATION_TYPE_GLOBAL = 1
NOTIFICATION_TYPE_WOD = 2
NOTIFICATION_TYPE_HEAT = 3
NOTIFICATION_TYPE_DIVISION = 4

# handled by events listeners
NOTIFICATION_TYPE_TEST = 5
NOTIFICATION_TYPE_SCORE = 6

# sorted in app
NOTIFICATION_TYPE_GENERAL = 1
NOTIFICATION_TYPE_TARGET = 2
NOTIFICATION_TYPE_FAVORITE = 3
